var group___direct3_d9 =
[
    [ "D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html", [
      [ "RenderTargetIterator", "class_ogre_1_1_d3_d9_render_system.html#a50a15a7bbc1beca5c91b6584a3060f1b", null ],
      [ "MultiheadUseType", "class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652f", [
        [ "mutAuto", "class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652fa25921c72928c345bce879cdeb59ea4de", null ],
        [ "mutYes", "class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652faf9d4681736aed408d4446783840b775f", null ],
        [ "mutNo", "class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652fa0e39e4e40a49121c32929470d9829f38", null ]
      ] ],
      [ "D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html#a14dbc5ade147a1ff11f7f7e2dff70053", null ],
      [ "~D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html#a5fcc5cf6ff472ea542bb69aeb48b9b01", null ],
      [ "initConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#a7c380aa6256e6ad8cd0278cfd4108515", null ],
      [ "validateConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#ac674dcd0e1b47a07723fe341f06eef6d", null ],
      [ "_initialise", "class_ogre_1_1_d3_d9_render_system.html#adbab61a827e8d9fd7c669ae7824d1b4f", null ],
      [ "_createRenderWindow", "class_ogre_1_1_d3_d9_render_system.html#a35c27788a6eedcc44b520fc17077f770", null ],
      [ "_createRenderWindows", "class_ogre_1_1_d3_d9_render_system.html#af2e127de3a611d547520a667fe067f29", null ],
      [ "_createDepthBufferFor", "class_ogre_1_1_d3_d9_render_system.html#abd43de1c83a36316e1c62cda7d2ef31f", null ],
      [ "_addManualDepthBuffer", "class_ogre_1_1_d3_d9_render_system.html#a4bd873491b6eb59dbadce27e1d88e902", null ],
      [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#a3c813348d2b65c9bcc7076811c5be436", null ],
      [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#affaba55ebbb835d47398ba424d2191cf", null ],
      [ "_setRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a195727cf757652f7f744a0fa27d19ea8", null ],
      [ "createMultiRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a65753b25abed94453cb78684920fbc93", null ],
      [ "detachRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a81f207d2d2010d656f55e87d14a87f89", null ],
      [ "getErrorDescription", "class_ogre_1_1_d3_d9_render_system.html#aaeb93c2e45c81e44b79eb7c2d37bea84", null ],
      [ "getName", "class_ogre_1_1_d3_d9_render_system.html#a6d9c10b490440524ea0b5760e7f486c9", null ],
      [ "setConfigOption", "class_ogre_1_1_d3_d9_render_system.html#a1f3c8023280ce8b5915434b2e7f52d20", null ],
      [ "reinitialise", "class_ogre_1_1_d3_d9_render_system.html#aad47c7460bff0b9a631b3eb17e296309", null ],
      [ "shutdown", "class_ogre_1_1_d3_d9_render_system.html#af14f1a6b539a896178cebfd8a6282fa7", null ],
      [ "setAmbientLight", "class_ogre_1_1_d3_d9_render_system.html#a5c0492ef2b162b8d0297e355c6d93592", null ],
      [ "setShadingType", "class_ogre_1_1_d3_d9_render_system.html#aec34535d0f59c1eb5a2414a210b0a7c3", null ],
      [ "setLightingEnabled", "class_ogre_1_1_d3_d9_render_system.html#adeae40b2bceb2c09b225fec8a80cdfeb", null ],
      [ "destroyRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a13fb04ce75bdf6920f3ce3628a19b610", null ],
      [ "getColourVertexElementType", "class_ogre_1_1_d3_d9_render_system.html#a1725114e0149f084486dc60abc62bbdc", null ],
      [ "setStencilCheckEnabled", "class_ogre_1_1_d3_d9_render_system.html#a17c198d30e84af9d8456b3f9198df09e", null ],
      [ "setStencilBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a8aad4909174796d54e9b1b56784c4baf", null ],
      [ "setNormaliseNormals", "class_ogre_1_1_d3_d9_render_system.html#aec42c90e719c2c1d2581a906e5120ff7", null ],
      [ "_useLights", "class_ogre_1_1_d3_d9_render_system.html#a1ed8dc6bed45eea7372025d8c8b7a67a", null ],
      [ "_setWorldMatrix", "class_ogre_1_1_d3_d9_render_system.html#a736da4898f04646bfc42e7b7d70e0ca7", null ],
      [ "_setViewMatrix", "class_ogre_1_1_d3_d9_render_system.html#af879a2bcdca5a9c4e944cb2976786a40", null ],
      [ "_setProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#a1fd0bcf3a5888f44e241e964a0532c98", null ],
      [ "_setSurfaceParams", "class_ogre_1_1_d3_d9_render_system.html#a868c258f27f871c839f24505c1542caa", null ],
      [ "_setPointSpritesEnabled", "class_ogre_1_1_d3_d9_render_system.html#a8087fcbe4777015df90f574b61fdfa67", null ],
      [ "_setPointParameters", "class_ogre_1_1_d3_d9_render_system.html#a82e47ef0c94c5f7d87199151ca811ff5", null ],
      [ "_setTexture", "class_ogre_1_1_d3_d9_render_system.html#acc8659aa8149972ca8c1175199110d7d", null ],
      [ "_setSampler", "class_ogre_1_1_d3_d9_render_system.html#a7319688813f35bb96dadbf22075b900b", null ],
      [ "_setVertexTexture", "class_ogre_1_1_d3_d9_render_system.html#a349ff5d559210fe9d1b733add4ddd350", null ],
      [ "_disableTextureUnit", "class_ogre_1_1_d3_d9_render_system.html#a0f35bab2afa97804cf8323d0205cd0c5", null ],
      [ "_setTextureCoordSet", "class_ogre_1_1_d3_d9_render_system.html#acfaf7c8ec448362a48a5ab1a026909dd", null ],
      [ "_setTextureCoordCalculation", "class_ogre_1_1_d3_d9_render_system.html#aa54b0c2ad942d41897c0b8a0a8e44166", null ],
      [ "_setTextureBlendMode", "class_ogre_1_1_d3_d9_render_system.html#ad0ce107404650d8b2ba8fcfba1448b60", null ],
      [ "_setTextureAddressingMode", "class_ogre_1_1_d3_d9_render_system.html#a6d7e92fba6760452e19d7a414ccc8672", null ],
      [ "_setTextureBorderColour", "class_ogre_1_1_d3_d9_render_system.html#a8f2284cd8c24afda7c14f9570f400698", null ],
      [ "_setTextureMipmapBias", "class_ogre_1_1_d3_d9_render_system.html#a4f573f2b71583712a1dac603f6917f98", null ],
      [ "_setTextureMatrix", "class_ogre_1_1_d3_d9_render_system.html#aaf51e7092d88a781953f3d0d0048eb52", null ],
      [ "_setSeparateSceneBlending", "class_ogre_1_1_d3_d9_render_system.html#aebfca89852cb822a7dcfe3aa5288999f", null ],
      [ "_setAlphaRejectSettings", "class_ogre_1_1_d3_d9_render_system.html#ab63c18908e608834b601298afd2da197", null ],
      [ "_setViewport", "class_ogre_1_1_d3_d9_render_system.html#a85ad53d4f860030b319ce0420f4ece2a", null ],
      [ "_beginFrame", "class_ogre_1_1_d3_d9_render_system.html#a3b458922197e5a3502b29e9bfe016cdf", null ],
      [ "_pauseFrame", "class_ogre_1_1_d3_d9_render_system.html#a65482df447bced296f056b0962ceabbe", null ],
      [ "_resumeFrame", "class_ogre_1_1_d3_d9_render_system.html#a21e6f22c4f85330f8f546f4469f23fbe", null ],
      [ "_endFrame", "class_ogre_1_1_d3_d9_render_system.html#aff3564dce1811300a2d4e7a65e4e9c66", null ],
      [ "_setCullingMode", "class_ogre_1_1_d3_d9_render_system.html#a96a7b98979ad56646ad87c4e327098cd", null ],
      [ "_setDepthBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a0d4aad4a09e5ccb9edea8814b53c3142", null ],
      [ "_setDepthBufferCheckEnabled", "class_ogre_1_1_d3_d9_render_system.html#a28dd997892ac1cb3f0b5f2babfa112d7", null ],
      [ "_setColourBufferWriteEnabled", "class_ogre_1_1_d3_d9_render_system.html#a0f781d5921649ee87d5a0a1753b8e081", null ],
      [ "_setDepthBufferWriteEnabled", "class_ogre_1_1_d3_d9_render_system.html#aa44f574d9b7aeec5be3b652dbae21d79", null ],
      [ "_setDepthBufferFunction", "class_ogre_1_1_d3_d9_render_system.html#a87d8a1dde9baf36fdc68f5a36c983383", null ],
      [ "_setDepthBias", "class_ogre_1_1_d3_d9_render_system.html#a7830b7940977d3ad920d0984c06113be", null ],
      [ "_setFog", "class_ogre_1_1_d3_d9_render_system.html#a1e32bbf6fff565726a5e10ed5431691f", null ],
      [ "_convertProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#acdd1a102566c67c2ce3426f06179cdae", null ],
      [ "_makeProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#aee210728f2dbf51a5c3d44aef97b97f8", null ],
      [ "_makeProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#ae1446d8242022a9861ba1df3e34fdbff", null ],
      [ "_makeOrthoMatrix", "class_ogre_1_1_d3_d9_render_system.html#ae3fd00aee60751f2bb937a0d1f619520", null ],
      [ "_applyObliqueDepthProjection", "class_ogre_1_1_d3_d9_render_system.html#a1d48fd6f7eb6b12f9297f41d1a12a48c", null ],
      [ "_setPolygonMode", "class_ogre_1_1_d3_d9_render_system.html#a0d5d7d3f33d4a8a6ee1ce2e416d7320a", null ],
      [ "_setTextureUnitFiltering", "class_ogre_1_1_d3_d9_render_system.html#a2844693c27bb55b93af8098fd658fb38", null ],
      [ "_setTextureUnitCompareFunction", "class_ogre_1_1_d3_d9_render_system.html#a9e34d9fe95dbca71ec671b6372c0c5a8", null ],
      [ "_setTextureUnitCompareEnabled", "class_ogre_1_1_d3_d9_render_system.html#a497f1ce8b52f61c024848f513f2a7456", null ],
      [ "_setTextureLayerAnisotropy", "class_ogre_1_1_d3_d9_render_system.html#a665c77f780de89e0af79c3d774d9c2f6", null ],
      [ "setVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#a014e9b7fe6828806a7234f3115d029b8", null ],
      [ "setVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#ad11519e92283a6cb4186dc618e037eec", null ],
      [ "setVertexBufferBinding", "class_ogre_1_1_d3_d9_render_system.html#a1819f0182b2c7ee533cf1032786d6d08", null ],
      [ "setVertexBufferBinding", "class_ogre_1_1_d3_d9_render_system.html#a4e565e4d5edfeedc47f8cc10dbccc3df", null ],
      [ "_render", "class_ogre_1_1_d3_d9_render_system.html#ac95209c361f6d09fb6e0af0f6d4b4107", null ],
      [ "bindGpuProgram", "class_ogre_1_1_d3_d9_render_system.html#a82c436739e35880bf9a03d3296b93e4d", null ],
      [ "unbindGpuProgram", "class_ogre_1_1_d3_d9_render_system.html#a08255da85acf7431528d739c77d37ec3", null ],
      [ "bindGpuProgramParameters", "class_ogre_1_1_d3_d9_render_system.html#ad80a6a285980da1c47bebb4946596039", null ],
      [ "bindGpuProgramPassIterationParameters", "class_ogre_1_1_d3_d9_render_system.html#a89794d945fa06756b8fabab0aa400981", null ],
      [ "setScissorTest", "class_ogre_1_1_d3_d9_render_system.html#ada9466da79cf86fde16473cc8bf2c728", null ],
      [ "clearFrameBuffer", "class_ogre_1_1_d3_d9_render_system.html#a746af1925b9e07bfc96075b192c19333", null ],
      [ "setClipPlane", "class_ogre_1_1_d3_d9_render_system.html#a2c6b6c60a60e9bfbf784596e3273e34a", null ],
      [ "enableClipPlane", "class_ogre_1_1_d3_d9_render_system.html#aebb369ceba620861ccd3ff8a1cead931", null ],
      [ "createHardwareOcclusionQuery", "class_ogre_1_1_d3_d9_render_system.html#aec0537fc834208bf533b48001c9bdc96", null ],
      [ "getHorizontalTexelOffset", "class_ogre_1_1_d3_d9_render_system.html#aaa6341e3fe439fffeff5bfffa48ec0e6", null ],
      [ "getVerticalTexelOffset", "class_ogre_1_1_d3_d9_render_system.html#a39666e7dd9fc27b22c82b05715fb3ff5", null ],
      [ "getMinimumDepthInputValue", "class_ogre_1_1_d3_d9_render_system.html#a14c20f8c89b3ef2a8c71daa22f9f02bd", null ],
      [ "getMaximumDepthInputValue", "class_ogre_1_1_d3_d9_render_system.html#ab55596f38bfc1ba9721eaa121166d7a5", null ],
      [ "registerThread", "class_ogre_1_1_d3_d9_render_system.html#a7bbc4c2f2fcfdc3f4e0a6e01250e39b2", null ],
      [ "unregisterThread", "class_ogre_1_1_d3_d9_render_system.html#acca4cb7d57e8b3a190d4599e0f0ac340", null ],
      [ "preExtraThreadsStarted", "class_ogre_1_1_d3_d9_render_system.html#a1054440c7aa6a82c82c3062ecb0822d7", null ],
      [ "postExtraThreadsStarted", "class_ogre_1_1_d3_d9_render_system.html#add5efc1032e4e0cc1540811b1b68113d", null ],
      [ "isStaticBufferLockable", "class_ogre_1_1_d3_d9_render_system.html#abaa7a52e12f93b4dfe8cad18828ffb5b", null ],
      [ "IsActiveDeviceLost", "class_ogre_1_1_d3_d9_render_system.html#a683991dc15e1d0c67213b96f9ac7753b", null ],
      [ "isDirectX9Ex", "class_ogre_1_1_d3_d9_render_system.html#a377991202bcd3b2ade63fe13f0540039", null ],
      [ "getResourceManager", "class_ogre_1_1_d3_d9_render_system.html#a8cc447f47bc9fbf8dcb77fa9f10d4dde", null ],
      [ "getDeviceManager", "class_ogre_1_1_d3_d9_render_system.html#a6c54141586c08b65890364ad8ddcf563", null ],
      [ "getDirect3D9", "class_ogre_1_1_d3_d9_render_system.html#aa3f1a981206b7f55462997ed49b68de8", null ],
      [ "getResourceCreationDeviceCount", "class_ogre_1_1_d3_d9_render_system.html#af9b728ddf675afcecfafd0d4d335c63c", null ],
      [ "getResourceCreationDevice", "class_ogre_1_1_d3_d9_render_system.html#a429e0d14525aa4022c5bfd54847195cd", null ],
      [ "getActiveD3D9Device", "class_ogre_1_1_d3_d9_render_system.html#af275458fafa039df530a9b3242139d29", null ],
      [ "getActiveD3D9DeviceIfExists", "class_ogre_1_1_d3_d9_render_system.html#a4ce5bef3f937282cfd0c4290e66e0c8f", null ],
      [ "_getDepthStencilFormatFor", "class_ogre_1_1_d3_d9_render_system.html#a756e9227a2d0147e31100ce041d4f9cb", null ],
      [ "_checkTextureFilteringSupported", "class_ogre_1_1_d3_d9_render_system.html#a09b739bb7b2d3c3aff1fecece56e9baa", null ],
      [ "determineFSAASettings", "class_ogre_1_1_d3_d9_render_system.html#abeb5bc1a5691a572c5dc2f4775cf76c5", null ],
      [ "getDisplayMonitorCount", "class_ogre_1_1_d3_d9_render_system.html#a44795018c7a6f424849c23cb3947a240", null ],
      [ "hasAnisotropicMipMapFilter", "class_ogre_1_1_d3_d9_render_system.html#a659cb3dfd72379833b0b4898d99f9a48", null ],
      [ "beginProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#ac5910601e68f4c7c08370e2b74066d9b", null ],
      [ "endProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#ae849367c0ad6d28ecc8db5d95b3e56d7", null ],
      [ "markProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#a489d99fe770e4c105434ed13911ce350", null ],
      [ "fireDeviceEvent", "class_ogre_1_1_d3_d9_render_system.html#ace53b06d3e61511f9b2dc6156e31c9a9", null ],
      [ "getMultiheadUse", "class_ogre_1_1_d3_d9_render_system.html#a7f5e2beb4bd0d894ee99c6468ba20ee7", null ],
      [ "setDrawBuffer", "class_ogre_1_1_d3_d9_render_system.html#a869123f35563093de0f4fe68321b9b4b", null ],
      [ "createStereoDriver", "class_ogre_1_1_d3_d9_render_system.html#a296a4b8cb73c61dced451b6e23e95919", null ],
      [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
      [ "getConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#a4415ece805ed62ee16c8343c96766231", null ],
      [ "destroyHardwareOcclusionQuery", "class_ogre_1_1_d3_d9_render_system.html#ac4c60bf4c5d4347fd2b9346a90545e2b", null ],
      [ "getMutableCapabilities", "class_ogre_1_1_d3_d9_render_system.html#ab0aa0cedf1898f8cc70e290703b428c7", null ],
      [ "useCustomRenderSystemCapabilities", "class_ogre_1_1_d3_d9_render_system.html#afc69e09f59064b79f3bfd4402617d07a", null ],
      [ "setAmbientLight", "class_ogre_1_1_d3_d9_render_system.html#af2364f8648585cd4fb7bb16761b35b2d", null ],
      [ "setWBufferEnabled", "class_ogre_1_1_d3_d9_render_system.html#a01c339f6e89d82b526fb7725424a4263", null ],
      [ "getWBufferEnabled", "class_ogre_1_1_d3_d9_render_system.html#a644d2fd38872cf323c50f63148d27d02", null ],
      [ "destroyRenderWindow", "class_ogre_1_1_d3_d9_render_system.html#a65ddf1db4aa3f463e0479c240ffc3dc5", null ],
      [ "destroyRenderTexture", "class_ogre_1_1_d3_d9_render_system.html#a354ceaa02574d1cf68dcb5999b34df50", null ],
      [ "attachRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#ac7ce258ff899b1694a18e1d51e1a3ba0", null ],
      [ "getRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a096eb751bc772f0b557bff4016f81d40", null ],
      [ "getRenderTargetIterator", "class_ogre_1_1_d3_d9_render_system.html#a7f5db0e3c575554cbf78c8a038087923", null ],
      [ "getGlobalInstanceVertexBuffer", "class_ogre_1_1_d3_d9_render_system.html#ae6ca13a37487dbd84870979d83736099", null ],
      [ "setGlobalInstanceVertexBuffer", "class_ogre_1_1_d3_d9_render_system.html#a8790243eb7c7d5c1952c5b9e1727632b", null ],
      [ "getGlobalInstanceVertexBufferVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#a007dfcda22d0194db6fd20880784218c", null ],
      [ "setGlobalInstanceVertexBufferVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#ab6e90c2fc5e640a846bee08d25078fe4", null ],
      [ "getGlobalNumberOfInstances", "class_ogre_1_1_d3_d9_render_system.html#af41e08cc1bc54e34d0314f4c9ffa58f6", null ],
      [ "setGlobalNumberOfInstances", "class_ogre_1_1_d3_d9_render_system.html#a3e31b243ba86e2114925a99b2c2825e1", null ],
      [ "setDepthBufferFor", "class_ogre_1_1_d3_d9_render_system.html#a63c23bbd80d6862a54d471754d9bccf0", null ],
      [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_d3_d9_render_system.html#a008131b65568c0bf072ae3a96203d6c0", null ],
      [ "_setTextureUnitSettings", "class_ogre_1_1_d3_d9_render_system.html#ad504623eff0678f9f79b075f32673414", null ],
      [ "_setBindingType", "class_ogre_1_1_d3_d9_render_system.html#ae197c344b0b2dce1739e3c566c280f8c", null ],
      [ "_disableTextureUnitsFrom", "class_ogre_1_1_d3_d9_render_system.html#a68e0ecb23c3eba58b5aeb06d646ce4cd", null ],
      [ "_setLineWidth", "class_ogre_1_1_d3_d9_render_system.html#a40f99785cb4f728763712169cec19f29", null ],
      [ "_setTextureUnitFiltering", "class_ogre_1_1_d3_d9_render_system.html#adbc64c669661f87ee2f8db8dd18a0fe5", null ],
      [ "setColourBlendState", "class_ogre_1_1_d3_d9_render_system.html#a46abac034b2217b91ae66b334e1ca42f", null ],
      [ "_setSceneBlending", "class_ogre_1_1_d3_d9_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
      [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_d3_d9_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
      [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
      [ "_getViewport", "class_ogre_1_1_d3_d9_render_system.html#aa0cf9dc2df0748f3076c5f8f1f8064db", null ],
      [ "_getCullingMode", "class_ogre_1_1_d3_d9_render_system.html#acc15a085c3fc5970d5c028c79eadead3", null ],
      [ "_beginGeometryCount", "class_ogre_1_1_d3_d9_render_system.html#a385581061b5d8d9af914d0439392aa62", null ],
      [ "_getFaceCount", "class_ogre_1_1_d3_d9_render_system.html#abef8777c6302b9747a0caa97482a87f4", null ],
      [ "_getBatchCount", "class_ogre_1_1_d3_d9_render_system.html#ac419ed21d6b2427b142a81fbfcde2be3", null ],
      [ "_getVertexCount", "class_ogre_1_1_d3_d9_render_system.html#a46c964471b448ada768b766aca428b91", null ],
      [ "convertColourValue", "class_ogre_1_1_d3_d9_render_system.html#a324d50e3fc58177d8d9f05c5cfc7e3e8", null ],
      [ "_dispatchCompute", "class_ogre_1_1_d3_d9_render_system.html#a2c59487ad841c47a24b94d242b3a01af", null ],
      [ "getCapabilities", "class_ogre_1_1_d3_d9_render_system.html#ac4b66fe49129476323eba9bdca672a36", null ],
      [ "getDriverVersion", "class_ogre_1_1_d3_d9_render_system.html#a884fc9154ef8f4c1d17a7920460d81f2", null ],
      [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_d3_d9_render_system.html#aeb912c6c0bfc8bd8d0670448e0a5370a", null ],
      [ "isGpuProgramBound", "class_ogre_1_1_d3_d9_render_system.html#a6077b61e7511ae56887c67498f5282a1", null ],
      [ "getNativeShadingLanguageVersion", "class_ogre_1_1_d3_d9_render_system.html#a9d89d5e2e2f0c2c30e72032eae4482ec", null ],
      [ "setClipPlanes", "class_ogre_1_1_d3_d9_render_system.html#a23cc0a7d87b77ec3d0a34e92335bec1a", null ],
      [ "addClipPlane", "class_ogre_1_1_d3_d9_render_system.html#abe36b06513ccdd9daca4c6443144bcfc", null ],
      [ "resetClipPlanes", "class_ogre_1_1_d3_d9_render_system.html#a844d233fa4ba66a95e56c086f76287f9", null ],
      [ "_initRenderTargets", "class_ogre_1_1_d3_d9_render_system.html#aacdaca375b0736ea8b9fe660f17405ab", null ],
      [ "_notifyCameraRemoved", "class_ogre_1_1_d3_d9_render_system.html#aad4ebe6f669319f83fc44cf9d5a8f9cc", null ],
      [ "_updateAllRenderTargets", "class_ogre_1_1_d3_d9_render_system.html#a8ef6bbe5a63769cfe73319ac418624a8", null ],
      [ "_swapAllRenderTargetBuffers", "class_ogre_1_1_d3_d9_render_system.html#af942e9e362a20277c177c062879fbd51", null ],
      [ "setInvertVertexWinding", "class_ogre_1_1_d3_d9_render_system.html#a697f9a8c12f2d08ccc6185cd7992c238", null ],
      [ "getInvertVertexWinding", "class_ogre_1_1_d3_d9_render_system.html#aab1e7223855194c748fd71a7ccdc7a8d", null ],
      [ "setCurrentPassIterationCount", "class_ogre_1_1_d3_d9_render_system.html#a207d38c53699525e2e49ee167f9c8eb5", null ],
      [ "setDeriveDepthBias", "class_ogre_1_1_d3_d9_render_system.html#a9457d24c16b49968fb176b1c1443a8ed", null ],
      [ "setSharedListener", "class_ogre_1_1_d3_d9_render_system.html#ad4936a78d447c0e8be978117c47e9f98", null ],
      [ "getSharedListener", "class_ogre_1_1_d3_d9_render_system.html#af759d985eae38988d9a5b381b81dd22e", null ],
      [ "addListener", "class_ogre_1_1_d3_d9_render_system.html#aab79ebed3fd0691af1f51c6abd556d68", null ],
      [ "removeListener", "class_ogre_1_1_d3_d9_render_system.html#a4d1749c7f452237f6c7c46d186160772", null ],
      [ "getRenderSystemEvents", "class_ogre_1_1_d3_d9_render_system.html#aeb2ab8c57df243e75eff26155092fbfe", null ],
      [ "getCustomAttribute", "class_ogre_1_1_d3_d9_render_system.html#a97e2c11d3822c064ccb8ef0b52acf289", null ],
      [ "D3D9Device", "class_ogre_1_1_d3_d9_render_system.html#a62a49b9f66b36b9be215f88e190366a2", null ],
      [ "D3D9DeviceManager", "class_ogre_1_1_d3_d9_render_system.html#aec82c6ec0be39f7ecb3e0d165125a540", null ]
    ] ],
    [ "MAX_LIGHTS", "group___direct3_d9.html#ga737b417f16ea225cf15e8d4c23df53dc", null ]
];